# coding: utf-8
from __future__ import unicode_literals

import abc

import six


try:
    from typing import TYPE_CHECKING
except ImportError:
    TYPE_CHECKING = False

if TYPE_CHECKING:
    from typing import Any


@six.add_metaclass(abc.ABCMeta)
class BaseContent(object):
    """
    Базовый класс контента отчёта.

    Под контентом отчёта подразумевается объект использующийся для описания
    преобразования произвольных данных для заполнения отчёта в подготовленные
    данные для объекта отчёта.
    """
    @abc.abstractmethod
    def render(self,
               context  # type: Any
               ):  # type: (...) -> Any
        """
        Преобразование контекста отчёта в данные объекта отчёта.

        Под контекстом отчёта подразумеваются данные используемые для
        заполнения отчёта.

        :param context: Контекст отчёта
        :return: Данные объекта отчёта
        """
        raise NotImplementedError
