# coding: utf-8
from __future__ import unicode_literals

from report_writer.impl.xlsx.report.writers.base import BaseReportWriter
from report_writer.impl.xlsx.report.writers.simple import CellWriter
from report_writer.impl.xlsx.utils.coordinates import get_cells_range
from report_writer.impl.xlsx.utils.coordinates import get_coordinates


try:
    from typing import TYPE_CHECKING
except ImportError:
    TYPE_CHECKING = False

if TYPE_CHECKING:
    from typing import Any
    from typing import Type

    from report_writer.impl.xlsx.report.report_file import ReportFile


class MergeWriter(BaseReportWriter):
    """
    Писатель для объединения клеток.

    :param report: Файл отчёта
    :param width: Ширина объединения
    :param height: Высота объединения
    """
    def __init__(self,
                 report,  # type: ReportFile
                 height,  # type: int
                 width,  # type: int
                 ):  # type: (...) -> None
        super(MergeWriter, self).__init__(report)
        self._height = height  # type: int
        self._width = width  # type: int

    def write(self,
              row,  # type: int
              col,  # type: int
              data  # type: Any
              ):  # type: (...) -> None
        cells_range = get_cells_range(
            get_coordinates(row, col),
            get_coordinates(row + self._height - 1, col + self._width - 1))
        self._report.worksheet.merge_cells(cells_range)


class MergedCellWriter(MergeWriter):
    """
    Писатель объединённой клетки.
    """
    merge_writer_cls = MergeWriter  # type: Type[MergeWriter]

    def write(self,
              row,  # type: int
              col,  # type: int
              data  # type: Any
              ):  # type: (...) -> None
        super(MergedCellWriter, self).write(row, col, data)
        CellWriter(self._report).write(row, col, data)
